tdp_core [![Phovea][phovea-image]][phovea-url] [![NPM version][npm-image]][npm-url] [![Build Status][circleci-image]][circleci-url]
=====================

Target discovery platform for exploring rankings of genes, disease models, and other entities.

Installation
------------

```
git clone https://github.com/datavisyn/tdp_core.git
cd tdp_core
npm install
```

Testing
-------

```
npm test
```

Building
--------

```
npm run build
```



***

<a href="https://caleydo.org"><img src="http://caleydo.org/assets/images/logos/caleydo.svg" align="left" width="200px" hspace="10" vspace="6"></a>
This repository is part of **[Phovea](http://phovea.caleydo.org/)**, a platform for developing web-based visualization applications. For tutorials, API docs, and more information about the build and deployment process, see the [documentation page](http://phovea.caleydo.org).


[phovea-image]: https://img.shields.io/badge/Phovea-Client%20Plugin-F47D20.svg
[phovea-url]: https://phovea.caleydo.org
[npm-image]: https://badge.fury.io/js/tdp_core.svg
[npm-url]: https://npmjs.org/package/tdp_core
[circleci-image]: https://circleci.com/gh/datavisyn/tdp_core.svg?style=shield&circle-token=021e456dc4d0e7ae082476213aada47bc0fd864b
[circleci-url]: https://circleci.com/gh/datavisyn/tdp_core
